ExprKind

Enum ExprKind 

pub enum ExprKind {
Show 22 variants If { condition: Expr, then: Expr, else_: Option<Expr>, }, App { head: Expr, args: Vec<Expr>, generic_args: Vec<GenericValue>, bounds_impls: Vec<ImplExpr>, trait_: Option<(ImplExpr, Vec<GenericValue>)>, }, Literal(Literal), Array(Vec<Expr>), Construct { constructor: GlobalId, is_record: bool, is_struct: bool, fields: Vec<(GlobalId, Expr)>, base: Option<Expr>, }, Match { scrutinee: Expr, arms: Vec<Arm>, }, Borrow { mutable: bool, inner: Expr, }, AddressOf { mutable: bool, inner: Expr, }, Let { lhs: Pat, rhs: Expr, body: Expr, }, GlobalId(GlobalId), LocalId(LocalId), Ascription { e: Expr, ty: Ty, }, Assign { lhs: Lhs, value: Expr, }, Loop { body: Expr, kind: Box<LoopKind>, state: Option<LoopState>, control_flow: Option<ControlFlowKind>, label: Option<Symbol>, }, Break { value: Expr, label: Option<Symbol>, state: Option<Expr>, }, Return { value: Expr, }, Continue { label: Option<Symbol>, state: Option<Expr>, }, Closure { params: Vec<Pat>, body: Expr, captures: Vec<Expr>, }, Block { body: Expr, safety_mode: SafetyKind, }, Quote { contents: Quote, }, Resugared(ResugaredExprKind), Error(ErrorNode),
}
Describes the shape of an expression.

Variants



If

If expression.

Example:

if x > 0 { 1 } else { 2 }

Fields

condition: Expr

The boolean condition (x > 0 in the example).

then: Expr

The then branch (1 in the example).

else_: Option<Expr>

An optional else branch (Some(2)in the example).



App

Function application.

Example:

f(x, y)

Fields

head: Expr

The head of the function application (or, which function do we apply?).

args: Vec<Expr>

The arguments applied to the function.

generic_args: Vec<GenericValue>

The generic arguments applied to the function.

bounds_impls: Vec<ImplExpr>

If the function requires generic bounds to be called, bounds_impls is a vector of impl. expressions for those bounds.

trait_: Option<(ImplExpr, Vec<GenericValue>)>

If we apply an associated function, contains the impl. expr used.



Literal(Literal)

A literal value.

Example:

42, "hello"



Array(Vec<Expr>)

An array literal.

Example:

[1, 2, 3]



Construct

A constructor application

Example:

MyEnum::MyVariant { x : 1, ...base }

Fields

constructor: GlobalId

The identifier of the constructor we are building (MyEnum::MyVariant in the example).

is_record: bool

Are we constructing a record? E.g. a struct or a variant with named fields. (true in the example)

is_struct: bool

Is this a struct? Neaning, not a variant from an enum. (false in the example)

fields: Vec<(GlobalId, Expr)>

A list of fields ([(x, 1)] in the example).

base: Option<Expr>

The base expression, if any. (Some(base) in the example)



Match

A `match`` expression.

Example:

match x {
    pat1 => expr1,
    pat2 => expr2,
}

Fields

scrutinee: Expr

The expression on which we are matching. (x in the example)

arms: Vec<Arm>

The arms of the match. (pat1 => expr1 and pat2 => expr2 in the example)



Borrow

A reference expression.

Examples:

  • &xmutable: false
  • &mut xmutable: true

Fields

mutable: bool

Is the borrow mutable?

inner: Expr

The expression we are borrowing



AddressOf

Raw borrow

Example:

*const u8

Fields

mutable: bool

Is the raw pointer mutable?

inner: Expr

The expression on which we take a pointer



Let

A let expression used in expressions.

Example:

let x = 1; x + 1

Fields

lhs: Pat

The left-hand side of the let expression. (x in the example)

rhs: Expr

The right-hand side of the let expression. (1 in the example)

body: Expr

The body of the let. (x + 1 in the example)



GlobalId(GlobalId)

A global identifier.

Example:

std::mem::drop



LocalId(LocalId)

A local variable.

Example:

x



Ascription

Type ascription

Fields

e: Expr

The expression being ascribed.

ty: Ty

The type



Assign

Variable mutation

Example:

x = 1

Fields

lhs: Lhs

the left-hand side (place) of the assign

value: Expr

The value we are assigning



Loop

Loop

Example:

'label: loop { body }

Fields

body: Expr

The body of the loop.

kind: Box<LoopKind>

The kind of loop (e.g. while, loop, for…).

state: Option<LoopState>

An optional loop state, that makes explicit the state mutated by the loop.

control_flow: Option<ControlFlowKind>

What kind of control flow is performed by this loop?

label: Option<Symbol>

Optional loop label.



Break

The break exppression, that breaks out of a loop.

Example:

break 'label 3

Fields

value: Expr

The value we break with. By default, this is ().

Example:
loop { break 3; } + 3
label: Option<Symbol>

What loop shall we break? By default, the parent enclosing loop.

state: Option<Expr>

When a loop has a state (see ExprKind::Loop::state), this field state is Some(_). This carries the updated state for the loop.



Return

Return from a function.

Example:

return 1

Fields

value: Expr

The expression we return (1 in the example).



Continue

Continue (go to next loop iteration)

Example:

continue 'label

Fields

label: Option<Symbol>

The loop we continue.

state: Option<Expr>

When a loop has a state (see ExprKind::Loop::state), this field state is Some(_). This carries the updated state for the loop.



Closure

Closure (anonymous function)

Example:

|x| x

Fields

params: Vec<Pat>

The parameters of the closure

body: Expr

The body of the closure

captures: Vec<Expr>

The captured expressions



Block

Block of safe or unsafe expression

Example:

unsafe { ... }

Fields

body: Expr

The body of the block.

safety_mode: SafetyKind

The safety of the block.



Quote

A quote is an inlined piece of backend code.

Fields

contents: Quote

The contents of the quote.



Resugared(ResugaredExprKind)

A resugared expression. This variant is introduced before printing only. Phases must not produce this variant.



Error(ErrorNode)

Fallback constructor to carry errors.

Implementations

Source

impl ExprKind

pub fn standalone_fn_app( head: impl Into<FnAppHead>, generic_args: Vec<GenericValue>, args: Vec<Expr>, output_type: Ty, span: Span, ) -> Self

Creates a App node for a standalone function.

pub fn fn_app( head: impl Into<FnAppHead>, generic_args: Vec<GenericValue>, args: Vec<Expr>, output_type: Ty, bounds_impls: Vec<ImplExpr>, trait_: Option<(ImplExpr, Vec<GenericValue>)>, span: Span, ) -> Self

Creates a App node.

pub fn tuple(components: Vec<Expr>) -> Self

Creates a tuple out of a vector of components.

pub fn promote(self, ty: Ty, span: Span) -> Expr

Promote to an Expr

Source

impl ExprKind

pub fn into_expr(self, span: Span, ty: Ty, attributes: Vec<Attribute>) -> Expr

Convert to full Expr with type, span and attributes