ImplExprKind

Enum ImplExprKind 

pub enum ImplExprKind {
    Self_,
    Concrete(TraitGoal),
    LocalBound {
        id: Symbol,
    },
    Parent {
        impl_: ImplExpr,
        ident: ImplIdent,
    },
    Projection {
        impl_: ImplExpr,
        item: GlobalId,
        ident: ImplIdent,
    },
    ImplApp {
        impl_: ImplExpr,
        args: Vec<ImplExpr>,
    },
    Dyn,
    Builtin(TraitGoal),
    Error(ErrorNode),
}
Represents all the kinds of impl expr.

Example:

In the snippet below, the clone method on x corresponds to the implementation of Clone derived for Vec<T> (ImplApp) given the LocalBound on T.

fn f<T: Clone>(x: Vec<T>) -> Vec<T> {
  x.clone()
}

Variants



Self_

The trait implementation being defined.

Example:

The impl expr for Type: Trait used in self.f() is Self_.

impl Trait for Type {
    fn f(&self) {...}
    fn g(&self) {self.f()}
}


Concrete(TraitGoal)

A concrete impl block.

Example

impl Clone for Type { // Consider this `impl` is called `impl0`
    ...
}
fn f(x: Type) {
    x.clone() // Here `clone` comes from `Concrete(impl0)`
}


LocalBound

A bound introduced by a generic clause.

Example:

fn f<T: Clone>(x: T) -> T {
  x.clone() // Here the method comes from the bound `T: Clone`
}

Fields

id: Symbol

Local identifier to a bound.



Parent

A parent implementation.

Example:

trait SubTrait: Clone {}
fn f<T: SubTrait>(x: T) -> T {
  x.clone() // Here the method comes from the parent of the bound `T: SubTrait`
}

Fields

impl_: ImplExpr

Parent implementation

ident: ImplIdent

Which implementation to pick in the parent



Projection

A projected associated implementation.

Example:

In this snippet, T::Item is an AssociatedType where the subsequent ImplExpr is a type projection of ITerator.

fn f<T: Iterator>(x: T) -> Option<T::Item> {
    x.next()
}

Fields

impl_: ImplExpr

The base implementation from which we project

item: GlobalId

The item in the trait implemented by impl_

ident: ImplIdent

Which implementation to pick on the item



ImplApp

An instantiation of a generic implementation.

Example:

fn f<T: Clone>(x: Vec<T>) -> Vec<T> {
  x.clone() // The `Clone` implementation for `Vec` is instantiated with the local bound `T: Clone`
}

Fields

impl_: ImplExpr

The head of the application

args: Vec<ImplExpr>

The arguments of the application



Dyn

The implementation provided by a dyn.



Builtin(TraitGoal)

A trait implemented natively by rust.



Error(ErrorNode)

Fallback constructor to carry errors.