ItemKind

Enum ItemKind 

pub enum ItemKind {
    Fn {
        name: GlobalId,
        generics: Generics,
        body: Expr,
        params: Vec<Param>,
        safety: SafetyKind,
    },
    TyAlias {
        name: GlobalId,
        generics: Generics,
        ty: Ty,
    },
    Type {
        name: GlobalId,
        generics: Generics,
        variants: Vec<Variant>,
        is_struct: bool,
    },
    Trait {
        name: GlobalId,
        generics: Generics,
        items: Vec<TraitItem>,
        safety: SafetyKind,
    },
    Impl {
        generics: Generics,
        self_ty: Ty,
        of_trait: (GlobalId, Vec<GenericValue>),
        items: Vec<ImplItem>,
        parent_bounds: Vec<(ImplExpr, ImplIdent)>,
    },
    Alias {
        name: GlobalId,
        item: GlobalId,
    },
    Use {
        path: Vec<String>,
        is_external: bool,
        rename: Option<String>,
    },
    Quote {
        quote: Quote,
        origin: ItemQuoteOrigin,
    },
    RustModule,
    Error(ErrorNode),
    Resugared(ResugaredItemKind),
    NotImplementedYet,
}
A top-level item in the module.

Variants



Fn

A function or constant item.

Example:

fn add<T: Clone>(x: i32, y: i32) -> i32 {
    x + y
}

Constants are represented as functions of arity zero, while functions always have a non-zero arity.

Fields

name: GlobalId

The identifier of the function.

Example:

add

generics: Generics

The generic arguments and constraints of the function.

Example:

the generic type T and the constraint T: Clone

body: Expr

The body of the function

Example:

x + y

params: Vec<Param>

The parameters of the function.

Example:

x: i32, y: i32

safety: SafetyKind

The safety of the function.



TyAlias

A type alias.

Example:

type A = u8;

Fields

name: GlobalId

Name of the alias

Example:

A

generics: Generics

Generic arguments and constraints

ty: Ty

Original type

Example:

u8



Type

A type definition (struct or enum)

Example:

enum A {B, C}
struct S {f: u8}

Fields

name: GlobalId

Name of this type

Example:

A, S

generics: Generics

Generic parameters and constraints

variants: Vec<Variant>

Variants

Example:

{B, C}

is_struct: bool

Is this a struct (or an enum)



Trait

A trait definition.

Example:

trait T<A> {
    type Assoc;
    fn m(x: Self::Assoc, y: Self) -> A;
}

Fields

name: GlobalId

Name of this trait

Example:

T

generics: Generics

Generic parameters and constraints

Example:

<A>

items: Vec<TraitItem>

Items required to implement the trait

Example:

type Assoc;, fn m ...;

safety: SafetyKind

Safe or unsafe



Impl

A trait implementation.

Example:

impl T<u8> for u16 {
    type Assoc = u32;
    fn m(x: u32, y: u16) -> u8 {
        (x as u8) + (y as u8)
    }
}

Fields

generics: Generics

Generic arguments and constraints

self_ty: Ty

The type we implement the trait for

Example:

u16

of_trait: (GlobalId, Vec<GenericValue>)

Instantiated trait that is being implemented

Example:

T<u8>

items: Vec<ImplItem>

Items in this impl

Example:

fn m ..., type Assoc ...

parent_bounds: Vec<(ImplExpr, ImplIdent)>

Implementations of traits required for this impl



Alias

Internal node introduced by phases, corresponds to an alias to any item.

Fields

name: GlobalId

New name

item: GlobalId

Original name



Use

A use statement

Fields

path: Vec<String>

Path to used item(s)

is_external: bool

Comes from external crate

rename: Option<String>

Optional as



Quote

A Quote node is inserted by phase TransformHaxLibInline to deal with some hax_lib features. For example insertion of verbatim backend code.

Fields

quote: Quote

Content of the quote

origin: ItemQuoteOrigin

Description of the quote target position



RustModule

A Rust module (mod, inline or not). This exists solely because modules can have attributes relevant to the hax engine.



Error(ErrorNode)

Fallback constructor to carry errors.



Resugared(ResugaredItemKind)

A resugared item. This variant is introduced before printing only. Phases must not produce this variant.



NotImplementedYet

Item that is not implemented yet

Implementations

Source

impl ItemKind

pub fn promote(self, ident: GlobalId, span: Span) -> Item

Promote to an item