pub struct LocalId(pub Symbol);Expand description
Local identifier
Tuple Fields
0: SymbolTrait Implementations
Sourceimpl AstVisitable for LocalId
impl AstVisitable for LocalId
Sourcefn drive_map<V: AstVisitorMut>(&mut self, v: &mut V)
fn drive_map<V: AstVisitorMut>(&mut self, v: &mut V)
Recursively visit this type with the provided visitor. This calls the visitor’s
visit_$any
method if it exists, otherwise visit_inner.Sourcefn drive<V: AstVisitor>(&self, v: &mut V)
fn drive<V: AstVisitor>(&self, v: &mut V)
Recursively visit this type with the provided visitor. This calls the visitor’s
visit_$any
method if it exists, otherwise visit_inner.Sourceimpl AstVisitable for LocalId
impl AstVisitable for LocalId
Sourcefn drive<V: AstEarlyExitVisitor>(&self, v: &mut V) -> ControlFlow<V::Break>
fn drive<V: AstEarlyExitVisitor>(&self, v: &mut V) -> ControlFlow<V::Break>
Recursively visit this type with the provided visitor. This calls the visitor’s
visit_$any
method if it exists, otherwise visit_inner.Sourcefn drive_mut<V: AstEarlyExitVisitorMut>(
&mut self,
v: &mut V,
) -> ControlFlow<V::Break>
fn drive_mut<V: AstEarlyExitVisitorMut>( &mut self, v: &mut V, ) -> ControlFlow<V::Break>
Recursively visit this type with the provided visitor. This calls the visitor’s
visit_$any
method if it exists, otherwise visit_inner.Sourceimpl<'de> Deserialize<'de> for LocalId
impl<'de> Deserialize<'de> for LocalId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'s, V> Drive<'s, V> for LocalId
impl<'s, V> Drive<'s, V> for LocalId
Sourcefn drive_inner(&'s self, visitor: &mut V) -> ControlFlow<V::Break>
fn drive_inner(&'s self, visitor: &mut V) -> ControlFlow<V::Break>
Call
v.visit() on the immediate contents of self.Sourceimpl<'s, V> DriveMut<'s, V> for LocalId
impl<'s, V> DriveMut<'s, V> for LocalId
Sourcefn drive_inner_mut(&'s mut self, visitor: &mut V) -> ControlFlow<V::Break>
fn drive_inner_mut(&'s mut self, visitor: &mut V) -> ControlFlow<V::Break>
Call
v.visit() on the immediate contents of self.Sourceimpl<'lt> From<&'lt LocalId> for FragmentRef<'lt>
impl<'lt> From<&'lt LocalId> for FragmentRef<'lt>
Sourceimpl From<&LocalIdent> for LocalId
impl From<&LocalIdent> for LocalId
Sourcefn from(value: &LocalIdent) -> Self
fn from(value: &LocalIdent) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for LocalId
impl JsonSchema for LocalId
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for LocalId
impl Ord for LocalId
Sourceimpl PartialOrd for LocalId
impl PartialOrd for LocalId
Sourceimpl<'a, 'b, A: 'a + Clone, P: PrettyAst<'a, 'b, A>> Pretty<'a, P, A> for &'b LocalId
impl<'a, 'b, A: 'a + Clone, P: PrettyAst<'a, 'b, A>> Pretty<'a, P, A> for &'b LocalId
Sourcefn pretty(self, allocator: &'a P) -> DocBuilder<'a, P, A>
fn pretty(self, allocator: &'a P) -> DocBuilder<'a, P, A>
Converts
self into a documentimpl Eq for LocalId
impl StructuralPartialEq for LocalId