pub enum ResugaredExprKind {
BinOp {
op: GlobalId,
lhs: Expr,
rhs: Expr,
generic_args: Vec<GenericValue>,
bounds_impls: Vec<ImplExpr>,
trait_: Option<(ImplExpr, Vec<GenericValue>)>,
},
Tuple(Vec<Expr>),
}Expand description
Resugared variants for expressions. This represent extra printing-only expressions, see super::ExprKind::Resugared.
Variants
BinOp
Binary operations (identified by resugaring) of the form f(e1, e2)
Fields

generic_args: Vec<GenericValue>The generic arguments applied to the function.

bounds_impls: Vec<ImplExpr>If the function requires generic bounds to be called, bounds_impls
is a vector of impl. expressions for those bounds.

trait_: Option<(ImplExpr, Vec<GenericValue>)>If we apply an associated function, contains the impl. expr used.
Tuple(Vec<Expr>)