pub struct Span {
pub data: Vec<Span>,
/* private fields */
}Expand description
Position of a Rust source
Fields
data: Vec<Span>A vector of spans as defined by the frontend. This is useful for supporting in a trivial way union of spans.
Implementations