pub struct ProjectionPredicate {
pub impl_: ImplExpr,
pub assoc_item: GlobalId,
pub ty: Ty,
}Expand description
A projection predicate expresses a constraint over an associated type:
ⓘ
fn f<T: Foo<S = String>>(...)In this example Foo has an associated type S.
Fields
impl_: ImplExprThe impl expression we project from
assoc_item: GlobalIdThe associated type being projected
ty: TyThe equality constraint on the associated type