pub struct Quote(pub Vec<QuoteContent>);Expand description
Represents an inlined piece of backend code
Tuple Fields
0: Vec<QuoteContent>Trait Implementations
Sourceimpl AnyFragment for Quote
impl AnyFragment for Quote
Sourcefn type_id() -> FragmentTypeId
fn type_id() -> FragmentTypeId
Get a type identifier for this fragment.
Sourcefn as_fragment<'a>(&'a self, type_id: FragmentTypeId) -> Option<FragmentRef<'a>>
fn as_fragment<'a>(&'a self, type_id: FragmentTypeId) -> Option<FragmentRef<'a>>
Coerce as a fragment reference.
Sourcefn as_owned_fragment(&self, type_id: FragmentTypeId) -> Option<Fragment>
fn as_owned_fragment(&self, type_id: FragmentTypeId) -> Option<Fragment>
Coerce as an owned fragment.
Sourceimpl AstVisitable for Quote
impl AstVisitable for Quote
Sourcefn drive_map<V: AstVisitorMut>(&mut self, v: &mut V)
fn drive_map<V: AstVisitorMut>(&mut self, v: &mut V)
Recursively visit this type with the provided visitor. This calls the visitor’s
visit_$any
method if it exists, otherwise visit_inner.Sourcefn drive<V: AstVisitor>(&self, v: &mut V)
fn drive<V: AstVisitor>(&self, v: &mut V)
Recursively visit this type with the provided visitor. This calls the visitor’s
visit_$any
method if it exists, otherwise visit_inner.Sourceimpl AstVisitable for Quote
impl AstVisitable for Quote
Sourcefn drive<V: AstEarlyExitVisitor>(&self, v: &mut V) -> ControlFlow<V::Break>
fn drive<V: AstEarlyExitVisitor>(&self, v: &mut V) -> ControlFlow<V::Break>
Recursively visit this type with the provided visitor. This calls the visitor’s
visit_$any
method if it exists, otherwise visit_inner.Sourcefn drive_mut<V: AstEarlyExitVisitorMut>(
&mut self,
v: &mut V,
) -> ControlFlow<V::Break>
fn drive_mut<V: AstEarlyExitVisitorMut>( &mut self, v: &mut V, ) -> ControlFlow<V::Break>
Recursively visit this type with the provided visitor. This calls the visitor’s
visit_$any
method if it exists, otherwise visit_inner.Sourceimpl<'de> Deserialize<'de> for Quote
impl<'de> Deserialize<'de> for Quote
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'s, V> Drive<'s, V> for Quote
impl<'s, V> Drive<'s, V> for Quote
Sourcefn drive_inner(&'s self, visitor: &mut V) -> ControlFlow<V::Break>
fn drive_inner(&'s self, visitor: &mut V) -> ControlFlow<V::Break>
Call
v.visit() on the immediate contents of self.Sourceimpl<'s, V> DriveMut<'s, V> for Quote
impl<'s, V> DriveMut<'s, V> for Quote
Sourcefn drive_inner_mut(&'s mut self, visitor: &mut V) -> ControlFlow<V::Break>
fn drive_inner_mut(&'s mut self, visitor: &mut V) -> ControlFlow<V::Break>
Call
v.visit() on the immediate contents of self.impl Eq for Quote
Sourceimpl<'lt> From<&'lt Quote> for FragmentRef<'lt>
impl<'lt> From<&'lt Quote> for FragmentRef<'lt>
Sourceimpl JsonSchema for Quote
impl JsonSchema for Quote
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for Quote
impl Ord for Quote
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Quote
impl PartialOrd for Quote
impl StructuralPartialEq for Quote
Sourceimpl<A: 'static + Clone, P: PrettyAst<A>> ToDocument<P, A> for Quote
impl<A: 'static + Clone, P: PrettyAst<A>> ToDocument<P, A> for Quote
Sourcefn to_document(&self, printer: &P) -> DocBuilder<A>
fn to_document(&self, printer: &P) -> DocBuilder<A>
Produce a document using the provided printer reference.