pub enum FnAppHead {
GlobalId(GlobalId),
ExprKind(ExprKind),
Expr(Expr),
}Expand description
Helper enum that describes what can serve as function application heads.
This is an helper that is useful for [ExprKind::fn_application].
Variants
GlobalId(GlobalId)
A global identifier
ExprKind(ExprKind)
An expression kind
Expr(Expr)
A full blown expression