ErrorWrapper

Struct ErrorWrapper 

pub struct ErrorWrapper<'a, V>(pub &'a mut V);
A visitor wrapper that automatically collects errors in ErrorNodes. Coupled with the trait VisitorWithErrors, this provides an error method on a visitor that can be used to throw errors, which will be automatically inlined in the AST on the closest error-capable node.

Tuple Fields

0: &'a mut V