pub struct LinkedItemGraph { /* private fields */ }Expand description
A graph of items connected via the hax attribute AttrPayload::AssociatedItem and UUIDs.
Implementations
Sourceimpl LinkedItemGraph
impl LinkedItemGraph
Sourcepub fn new(items: &[Item], context: Context) -> Self
pub fn new(items: &[Item], context: Context) -> Self
Clone items marked with UUIDs attributes to build a graph of linked items. This graph clones the items that represent linked items: e.g. pre and post conditions.
Sourcepub fn linked_items_iter(
&self,
item: &impl HasMetadata,
) -> impl Iterator<Item = (AssociationRole, Result<&Item, DiagnosticInfo>)>
pub fn linked_items_iter( &self, item: &impl HasMetadata, ) -> impl Iterator<Item = (AssociationRole, Result<&Item, DiagnosticInfo>)>
Given a graph and an item item, returns an iterator of the various items that are linked with item.
Sourcepub fn linked_items(
&self,
item: &impl HasMetadata,
) -> HashMap<AssociationRole, Vec<Result<&Item, DiagnosticInfo>>>
pub fn linked_items( &self, item: &impl HasMetadata, ) -> HashMap<AssociationRole, Vec<Result<&Item, DiagnosticInfo>>>
Returns the items linked to a given item.
Sourcepub fn fn_like_linked_expressions(
&self,
item: &impl HasMetadata,
self_id: Option<LocalId>,
) -> FnLikeAssocatedExpressions
pub fn fn_like_linked_expressions( &self, item: &impl HasMetadata, self_id: Option<LocalId>, ) -> FnLikeAssocatedExpressions
Returns the precondition, postcondition and decreases clause, if any, for a given item.
When operating on a linked function, self_id is the local identifier of self.