pub struct ProofAttributes {
pub proof: Option<String>,
pub pure_requires_proof: Option<String>,
pub pure_ensures_proof: Option<String>,
pub proof_method: Option<ProofMethod>,
}Expand description
The various linked expressions one can usually find on a (linked or not) function.
Fields
proof: Option<String>A custom proof, see [hax_lib::lean::proof]
pure_requires_proof: Option<String>A proof that the precondition is pure, see [hax_lib::lean::pure_requires_proof]
pure_ensures_proof: Option<String>A proof that the postcondition is pure, see [hax_lib::lean::pure_ensures_proof]
proof_method: Option<ProofMethod>A proof method, see [hax_lib::lean::proof_method]