Module lean

Module lean 

The Lean backend

This module defines the trait implementations to export the rust ast to Pretty::Doc type, which can in turn be exported to string (or, eventually, source maps).

Structs

LeanBackend
The Lean backend
LeanPrinter
The Lean printer