LeanPrinter

Struct LeanPrinter 

pub struct LeanPrinter { /* private fields */ }
The Lean printer

Implementations

Source

impl LeanPrinter

pub fn is_hax_core_models_extraction_mode(&self) -> bool

Checks if we are extracting core models to be able to use different namespeacing when referring to core.

pub fn render_id(&self, id: &GlobalId) -> String

Render a global id using the Rendering strategy of the Lean printer. Works for both concrete and projector ids. TODO: https://github.com/cryspen/hax/issues/1660

pub fn render_last(&self, id: &GlobalId) -> String

Renders the last, most local part of an id. Used for named arguments of constructors.

pub fn render_with_injection(&self, id: &GlobalId, injection: &String) -> String

Inject an identifier in before-last position while rendering TODO: use DefIdInner::kind for this instead (https://github.com/cryspen/hax/issues/1877)

Source

impl LeanPrinter

pub fn arguments<A: 'static + Clone, D>( &self, fields: &[(GlobalId, D)], is_record: &bool, ) -> DocBuilder<A>
where D: ToDocument<Self, A>,

Prints arguments a variant or constructor of struct, using named or unamed arguments based on the is_record flag. Used for both expressions and patterns