pretty_ast_docs

Macro pretty_ast_docs 

macro_rules! pretty_ast_docs {
    ($printer: expr, $docs:expr) => { ... };
    ($printer: expr, $($docs:expr),*$(,)?) => { ... };
}
Expand a list of values into documents and concatenate them in order.

This helper mirrors pretty::docs! but automatically calls ToDocumentOwned::to_document_owned on each argument before appending it to the accumulator that starts as PrettyAstExt::nil.