todo_document

Macro todo_document 

macro_rules! todo_document {
    ($allocator:ident, issue $issue:literal) => { ... };
    ($allocator:ident, issue $issue:literal, $($tt:tt)*) => { ... };
    ($allocator:ident,) => { ... };
    ($allocator:ident, $($tt:tt)*) => { ... };
}
Similar to std::todo, but returns a document instead of panicking with a message. In addition, todo_document! accepts a prefix to point to a specific issue number.

Examples:

  • todo_document!(allocator)
  • todo_document!(allocator, "This is a todo")
  • todo_document!(allocator, issue 42)
  • todo_document!(allocator, issue 42, "This is a todo")