Module codegen

Module codegen 

Global identifiers are built around DefId that comes out of the hax frontend. We use the Rust engine itself to produce the names: we run hax on the engine/names crate, we extract identifiers from the resulting AST, and we expose them back as Rust functions here.

Functions

export_def_ids_to_mod
Finds all DefIds in items, and produce a Rust module exposing them.