Module ocaml_engine

Module ocaml_engine 

This module implements an interface to the OCaml hax engine. Via this interface, the rust engine can communicate with the OCaml engine, and reuse some of its components.

Structs

Meta
The metadata required to perform a query.
Query
A query for the OCaml engine

Enums

ExtendedFromEngine
Extends the common FromEngine messages with one extra case: Response.
QueryKind
The payload of the query. Response below mirrors this enum to represent the response from the engine.
Response
A Response after a Query

Functions

initialize
Initialize query metadata.