QueryKind

Enum QueryKind 

pub enum QueryKind {
    ImportThir {
        input: Vec<Item<ThirBody>>,
        translation_options: TranslationOptions,
    },
    ApplyPhases {
        phases: Vec<String>,
        input: Vec<Item>,
    },
    Print {
        printer: Backend<()>,
        input: Vec<Item>,
    },
}
The payload of the query. Response below mirrors this enum to represent the response from the engine.

Variants



ImportThir

Ask the OCaml engine to import the given THIR from the frontend

Fields

input: Vec<Item<ThirBody>>

The input THIR items

translation_options: TranslationOptions

Translation options which contains include clauses (items filtering)



ApplyPhases

Ask the OCaml engine to run given phases on given items

Fields

phases: Vec<String>

The phases to run. See untyped_phases.ml.

input: Vec<Item>

The items on which the phases will be applied.



Print

Ask the OCaml engine to call an OCaml printer

Fields

printer: Backend<()>

Which printer to use

input: Vec<Item>

The items after applying the phases.

Implementations

Source

impl QueryKind

pub fn execute(self, table: Option<Table>) -> Option<Response>

Execute the query synchronously.