Module default

Module default 

Default rendering helpers used by RenderView’s blanket implementations.

You can call these directly when composing your own renderer, or override the trait methods to change behavior selectively.

Functions

render_path_segment
Default rendering of a single PathSegment into display atoms.
render_suffix
Default suffix rendering
render_unnamed_path_segment_payload
Default mapping of unnamed payloads to printable symbols.