FunctionsToConstants

Struct FunctionsToConstants 

pub struct FunctionsToConstants;
Transforms ItemKind::Fn of arity zero into ResugaredItemKind::Constant. Rust const items are encoded by the ImportThir phase of the hax engine as function of arity zero. Functions of arity zero themselves are encoded as functions operating on one argument of type ().