pub enum ControlFlowKind {
BreakOnly,
BreakOrReturn,
}Expand description
This is a marker to describe what control flow is present in a loop.
It is added by phase DropReturnBreakContinue and the information is used in
FunctionalizeLoops. We need it to replace the control flow nodes of the AST
by an encoding in the ControlFlow enum.
Variants
BreakOnly
Contains no return, maybe some breaks
BreakOrReturn
Contains both at least one return and maybe some breaks