pub enum ItemKind {
Fn {
name: GlobalId,
generics: Generics,
body: Expr,
params: Vec<Param>,
safety: SafetyKind,
},
TyAlias {
name: GlobalId,
generics: Generics,
ty: Ty,
},
Type {
name: GlobalId,
generics: Generics,
variants: Vec<Variant>,
is_struct: bool,
},
Trait {
name: GlobalId,
generics: Generics,
items: Vec<TraitItem>,
safety: SafetyKind,
},
Impl {
generics: Generics,
self_ty: Ty,
of_trait: (GlobalId, Vec<GenericValue>),
items: Vec<ImplItem>,
parent_bounds: Vec<(ImplExpr, ImplIdent)>,
},
Alias {
name: GlobalId,
item: GlobalId,
},
Use {
path: Vec<String>,
is_external: bool,
rename: Option<String>,
},
Quote {
quote: Quote,
origin: ItemQuoteOrigin,
},
RustModule,
Error(ErrorNode),
Resugared(ResugaredItemKind),
NotImplementedYet,
}Expand description
A top-level item in the module.
Variants
Fn
A function or constant item.
Example:
fn add<T: Clone>(x: i32, y: i32) -> i32 {
x + y
}Constants are represented as functions of arity zero, while functions always have a non-zero arity.
Fields
generics: GenericsThe generic arguments and constraints of the function.
Example:
the generic type T and the constraint T: Clone
safety: SafetyKindThe safety of the function.
TyAlias
Fields
Type
Fields
Trait
Fields
safety: SafetyKindSafe or unsafe
Impl
A trait implementation.
Example:
impl T<u8> for u16 {
type Assoc = u32;
fn m(x: u32, y: u16) -> u8 {
(x as u8) + (y as u8)
}
}Fields
of_trait: (GlobalId, Vec<GenericValue>)Alias
Internal node introduced by phases, corresponds to an alias to any item.
Use
A use statement
Fields
Quote
A Quote node is inserted by phase TransformHaxLibInline to deal with some hax_lib features.
For example insertion of verbatim backend code.
Fields
origin: ItemQuoteOriginDescription of the quote target position
RustModule
A Rust module (mod, inline or not).
This exists solely because modules can have attributes relevant to the hax engine.
Error(ErrorNode)
Fallback constructor to carry errors.
Resugared(ResugaredItemKind)
A resugared item. This variant is introduced before printing only. Phases must not produce this variant.
NotImplementedYet
Item that is not implemented yet
Implementations