pub struct ImplExpr {
pub kind: Box<ImplExprKind>,
pub goal: TraitGoal,
}Expand description
An ImplExpr describes the full data of a trait implementation. Because of
generics, this may need to combine several concrete trait implementation
items. For example, ((1u8, 2u8), "hello").clone() combines the generic
implementation of Clone for (A, B) with the concrete implementations for
u8 and &str, represented as a tree.
Fields
kind: Box<ImplExprKind>The impl. expression itself.
goal: TraitGoalThe trait being implemented.