This module provides a collection of utilities to work on AST.
Modules
- mappers
- Useful visitor to map AST fragments.
Enums
- FnApp
Head - Helper enum that describes what can serve as function application heads.
This is an helper that is useful for [
ExprKind::fn_application].