pub struct ErrorWrapper<'a, V>(pub &'a mut V);Expand description
A visitor wrapper that automatically collects errors in ErrorNodes.
Coupled with the trait VisitorWithErrors, this provides an error
method on a visitor that can be used to throw errors, which will be
automatically inlined in the AST on the closest error-capable node.
Tuple Fields
0: &'a mut VTrait Implementations
Sourceimpl<'a, V: AstVisitorMut + VisitorWithErrors> AstVisitorMut for ErrorWrapper<'a, V>
impl<'a, V: AstVisitorMut + VisitorWithErrors> AstVisitorMut for ErrorWrapper<'a, V>
Sourcefn visit_inner<T>(&mut self, x: &mut T)
fn visit_inner<T>(&mut self, x: &mut T)
Visit the contents of
x. This calls self.visit() on each field of T. This
is available for any type whose contents are all #trait_name.Sourcefn visit_item(&mut self, x: &mut Item)
fn visit_item(&mut self, x: &mut Item)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn visit_pat(&mut self, x: &mut Pat)
fn visit_pat(&mut self, x: &mut Pat)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn visit_expr(&mut self, x: &mut Expr)
fn visit_expr(&mut self, x: &mut Expr)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn visit_ty(&mut self, x: &mut Ty)
fn visit_ty(&mut self, x: &mut Ty)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn visit<'a, T: AstVisitable>(&'a mut self, x: &mut T)
fn visit<'a, T: AstVisitable>(&'a mut self, x: &mut T)
Visit a visitable type. This calls the appropriate method of this trait on
x
(visit_$ty if it exists, visit_inner if not).Sourcefn visit_by_val<T: AstVisitable>(self, x: &mut T) -> Self
fn visit_by_val<T: AstVisitable>(self, x: &mut T) -> Self
Convenience alias for method chaining.
Sourcefn enter_expr(&mut self, x: &mut Expr)
fn enter_expr(&mut self, x: &mut Expr)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_expr(&mut self, x: &mut Expr)
fn exit_expr(&mut self, x: &mut Expr)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn enter_pat(&mut self, x: &mut Pat)
fn enter_pat(&mut self, x: &mut Pat)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_pat(&mut self, x: &mut Pat)
fn exit_pat(&mut self, x: &mut Pat)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_expr_kind(&mut self, x: &mut ExprKind)
fn visit_expr_kind(&mut self, x: &mut ExprKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_expr_kind(&mut self, x: &mut ExprKind)
fn enter_expr_kind(&mut self, x: &mut ExprKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_expr_kind(&mut self, x: &mut ExprKind)
fn exit_expr_kind(&mut self, x: &mut ExprKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_pat_kind(&mut self, x: &mut PatKind)
fn visit_pat_kind(&mut self, x: &mut PatKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_pat_kind(&mut self, x: &mut PatKind)
fn enter_pat_kind(&mut self, x: &mut PatKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_pat_kind(&mut self, x: &mut PatKind)
fn exit_pat_kind(&mut self, x: &mut PatKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn enter_ty(&mut self, x: &mut Ty)
fn enter_ty(&mut self, x: &mut Ty)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_ty(&mut self, x: &mut Ty)
fn exit_ty(&mut self, x: &mut Ty)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_ty_kind(&mut self, x: &mut TyKind)
fn visit_ty_kind(&mut self, x: &mut TyKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_ty_kind(&mut self, x: &mut TyKind)
fn enter_ty_kind(&mut self, x: &mut TyKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_ty_kind(&mut self, x: &mut TyKind)
fn exit_ty_kind(&mut self, x: &mut TyKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_metadata(&mut self, x: &mut Metadata)
fn visit_metadata(&mut self, x: &mut Metadata)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_metadata(&mut self, x: &mut Metadata)
fn enter_metadata(&mut self, x: &mut Metadata)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_metadata(&mut self, x: &mut Metadata)
fn exit_metadata(&mut self, x: &mut Metadata)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_literal(&mut self, x: &mut Literal)
fn visit_literal(&mut self, x: &mut Literal)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_literal(&mut self, x: &mut Literal)
fn enter_literal(&mut self, x: &mut Literal)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_literal(&mut self, x: &mut Literal)
fn exit_literal(&mut self, x: &mut Literal)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_local_id(&mut self, x: &mut LocalId)
fn visit_local_id(&mut self, x: &mut LocalId)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_local_id(&mut self, x: &mut LocalId)
fn enter_local_id(&mut self, x: &mut LocalId)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_local_id(&mut self, x: &mut LocalId)
fn exit_local_id(&mut self, x: &mut LocalId)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_lhs(&mut self, x: &mut Lhs)
fn visit_lhs(&mut self, x: &mut Lhs)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_lhs(&mut self, x: &mut Lhs)
fn enter_lhs(&mut self, x: &mut Lhs)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_lhs(&mut self, x: &mut Lhs)
fn exit_lhs(&mut self, x: &mut Lhs)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_symbol(&mut self, x: &mut Symbol)
fn visit_symbol(&mut self, x: &mut Symbol)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_symbol(&mut self, x: &mut Symbol)
fn enter_symbol(&mut self, x: &mut Symbol)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_symbol(&mut self, x: &mut Symbol)
fn exit_symbol(&mut self, x: &mut Symbol)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_loop_kind(&mut self, x: &mut LoopKind)
fn visit_loop_kind(&mut self, x: &mut LoopKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_loop_kind(&mut self, x: &mut LoopKind)
fn enter_loop_kind(&mut self, x: &mut LoopKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_loop_kind(&mut self, x: &mut LoopKind)
fn exit_loop_kind(&mut self, x: &mut LoopKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_safety_kind(&mut self, x: &mut SafetyKind)
fn visit_safety_kind(&mut self, x: &mut SafetyKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_safety_kind(&mut self, x: &mut SafetyKind)
fn enter_safety_kind(&mut self, x: &mut SafetyKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_safety_kind(&mut self, x: &mut SafetyKind)
fn exit_safety_kind(&mut self, x: &mut SafetyKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_quote(&mut self, x: &mut Quote)
fn visit_quote(&mut self, x: &mut Quote)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_quote(&mut self, x: &mut Quote)
fn enter_quote(&mut self, x: &mut Quote)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_quote(&mut self, x: &mut Quote)
fn exit_quote(&mut self, x: &mut Quote)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_spanned_ty(&mut self, x: &mut SpannedTy)
fn visit_spanned_ty(&mut self, x: &mut SpannedTy)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_spanned_ty(&mut self, x: &mut SpannedTy)
fn enter_spanned_ty(&mut self, x: &mut SpannedTy)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_spanned_ty(&mut self, x: &mut SpannedTy)
fn exit_spanned_ty(&mut self, x: &mut SpannedTy)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_binding_mode(&mut self, x: &mut BindingMode)
fn visit_binding_mode(&mut self, x: &mut BindingMode)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_binding_mode(&mut self, x: &mut BindingMode)
fn enter_binding_mode(&mut self, x: &mut BindingMode)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_binding_mode(&mut self, x: &mut BindingMode)
fn exit_binding_mode(&mut self, x: &mut BindingMode)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_primitive_ty(&mut self, x: &mut PrimitiveTy)
fn visit_primitive_ty(&mut self, x: &mut PrimitiveTy)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_primitive_ty(&mut self, x: &mut PrimitiveTy)
fn enter_primitive_ty(&mut self, x: &mut PrimitiveTy)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_primitive_ty(&mut self, x: &mut PrimitiveTy)
fn exit_primitive_ty(&mut self, x: &mut PrimitiveTy)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_region(&mut self, x: &mut Region)
fn visit_region(&mut self, x: &mut Region)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_region(&mut self, x: &mut Region)
fn enter_region(&mut self, x: &mut Region)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_region(&mut self, x: &mut Region)
fn exit_region(&mut self, x: &mut Region)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_impl_expr(&mut self, x: &mut ImplExpr)
fn visit_impl_expr(&mut self, x: &mut ImplExpr)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_impl_expr(&mut self, x: &mut ImplExpr)
fn enter_impl_expr(&mut self, x: &mut ImplExpr)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_impl_expr(&mut self, x: &mut ImplExpr)
fn exit_impl_expr(&mut self, x: &mut ImplExpr)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_int_kind(&mut self, x: &mut IntKind)
fn visit_int_kind(&mut self, x: &mut IntKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_int_kind(&mut self, x: &mut IntKind)
fn enter_int_kind(&mut self, x: &mut IntKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_int_kind(&mut self, x: &mut IntKind)
fn exit_int_kind(&mut self, x: &mut IntKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_float_kind(&mut self, x: &mut FloatKind)
fn visit_float_kind(&mut self, x: &mut FloatKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_float_kind(&mut self, x: &mut FloatKind)
fn enter_float_kind(&mut self, x: &mut FloatKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_float_kind(&mut self, x: &mut FloatKind)
fn exit_float_kind(&mut self, x: &mut FloatKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_generic_value(&mut self, x: &mut GenericValue)
fn visit_generic_value(&mut self, x: &mut GenericValue)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_generic_value(&mut self, x: &mut GenericValue)
fn enter_generic_value(&mut self, x: &mut GenericValue)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_generic_value(&mut self, x: &mut GenericValue)
fn exit_generic_value(&mut self, x: &mut GenericValue)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_arm(&mut self, x: &mut Arm)
fn visit_arm(&mut self, x: &mut Arm)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_arm(&mut self, x: &mut Arm)
fn enter_arm(&mut self, x: &mut Arm)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_arm(&mut self, x: &mut Arm)
fn exit_arm(&mut self, x: &mut Arm)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_loop_state(&mut self, x: &mut LoopState)
fn visit_loop_state(&mut self, x: &mut LoopState)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_loop_state(&mut self, x: &mut LoopState)
fn enter_loop_state(&mut self, x: &mut LoopState)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_loop_state(&mut self, x: &mut LoopState)
fn exit_loop_state(&mut self, x: &mut LoopState)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_control_flow_kind(&mut self, x: &mut ControlFlowKind)
fn visit_control_flow_kind(&mut self, x: &mut ControlFlowKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_control_flow_kind(&mut self, x: &mut ControlFlowKind)
fn enter_control_flow_kind(&mut self, x: &mut ControlFlowKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_control_flow_kind(&mut self, x: &mut ControlFlowKind)
fn exit_control_flow_kind(&mut self, x: &mut ControlFlowKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_dyn_trait_goal(&mut self, x: &mut DynTraitGoal)
fn visit_dyn_trait_goal(&mut self, x: &mut DynTraitGoal)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_dyn_trait_goal(&mut self, x: &mut DynTraitGoal)
fn enter_dyn_trait_goal(&mut self, x: &mut DynTraitGoal)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_dyn_trait_goal(&mut self, x: &mut DynTraitGoal)
fn exit_dyn_trait_goal(&mut self, x: &mut DynTraitGoal)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_attribute(&mut self, x: &mut Attribute)
fn visit_attribute(&mut self, x: &mut Attribute)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_attribute(&mut self, x: &mut Attribute)
fn enter_attribute(&mut self, x: &mut Attribute)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_attribute(&mut self, x: &mut Attribute)
fn exit_attribute(&mut self, x: &mut Attribute)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_quote_content(&mut self, x: &mut QuoteContent)
fn visit_quote_content(&mut self, x: &mut QuoteContent)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_quote_content(&mut self, x: &mut QuoteContent)
fn enter_quote_content(&mut self, x: &mut QuoteContent)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_quote_content(&mut self, x: &mut QuoteContent)
fn exit_quote_content(&mut self, x: &mut QuoteContent)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_borrow_kind(&mut self, x: &mut BorrowKind)
fn visit_borrow_kind(&mut self, x: &mut BorrowKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_borrow_kind(&mut self, x: &mut BorrowKind)
fn enter_borrow_kind(&mut self, x: &mut BorrowKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_borrow_kind(&mut self, x: &mut BorrowKind)
fn exit_borrow_kind(&mut self, x: &mut BorrowKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_trait_goal(&mut self, x: &mut TraitGoal)
fn visit_trait_goal(&mut self, x: &mut TraitGoal)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_trait_goal(&mut self, x: &mut TraitGoal)
fn enter_trait_goal(&mut self, x: &mut TraitGoal)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_trait_goal(&mut self, x: &mut TraitGoal)
fn exit_trait_goal(&mut self, x: &mut TraitGoal)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_impl_expr_kind(&mut self, x: &mut ImplExprKind)
fn visit_impl_expr_kind(&mut self, x: &mut ImplExprKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_impl_expr_kind(&mut self, x: &mut ImplExprKind)
fn enter_impl_expr_kind(&mut self, x: &mut ImplExprKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_impl_expr_kind(&mut self, x: &mut ImplExprKind)
fn exit_impl_expr_kind(&mut self, x: &mut ImplExprKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_int_size(&mut self, x: &mut IntSize)
fn visit_int_size(&mut self, x: &mut IntSize)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_int_size(&mut self, x: &mut IntSize)
fn enter_int_size(&mut self, x: &mut IntSize)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_int_size(&mut self, x: &mut IntSize)
fn exit_int_size(&mut self, x: &mut IntSize)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_signedness(&mut self, x: &mut Signedness)
fn visit_signedness(&mut self, x: &mut Signedness)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_signedness(&mut self, x: &mut Signedness)
fn enter_signedness(&mut self, x: &mut Signedness)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_signedness(&mut self, x: &mut Signedness)
fn exit_signedness(&mut self, x: &mut Signedness)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_guard(&mut self, x: &mut Guard)
fn visit_guard(&mut self, x: &mut Guard)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_guard(&mut self, x: &mut Guard)
fn enter_guard(&mut self, x: &mut Guard)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_guard(&mut self, x: &mut Guard)
fn exit_guard(&mut self, x: &mut Guard)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_attribute_kind(&mut self, x: &mut AttributeKind)
fn visit_attribute_kind(&mut self, x: &mut AttributeKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_attribute_kind(&mut self, x: &mut AttributeKind)
fn enter_attribute_kind(&mut self, x: &mut AttributeKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_attribute_kind(&mut self, x: &mut AttributeKind)
fn exit_attribute_kind(&mut self, x: &mut AttributeKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_guard_kind(&mut self, x: &mut GuardKind)
fn visit_guard_kind(&mut self, x: &mut GuardKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_guard_kind(&mut self, x: &mut GuardKind)
fn enter_guard_kind(&mut self, x: &mut GuardKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_guard_kind(&mut self, x: &mut GuardKind)
fn exit_guard_kind(&mut self, x: &mut GuardKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_impl_item(&mut self, x: &mut ImplItem)
fn visit_impl_item(&mut self, x: &mut ImplItem)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_impl_item(&mut self, x: &mut ImplItem)
fn enter_impl_item(&mut self, x: &mut ImplItem)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_impl_item(&mut self, x: &mut ImplItem)
fn exit_impl_item(&mut self, x: &mut ImplItem)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_impl_item_kind(&mut self, x: &mut ImplItemKind)
fn visit_impl_item_kind(&mut self, x: &mut ImplItemKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_impl_item_kind(&mut self, x: &mut ImplItemKind)
fn enter_impl_item_kind(&mut self, x: &mut ImplItemKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_impl_item_kind(&mut self, x: &mut ImplItemKind)
fn exit_impl_item_kind(&mut self, x: &mut ImplItemKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_trait_item(&mut self, x: &mut TraitItem)
fn visit_trait_item(&mut self, x: &mut TraitItem)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_trait_item(&mut self, x: &mut TraitItem)
fn enter_trait_item(&mut self, x: &mut TraitItem)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_trait_item(&mut self, x: &mut TraitItem)
fn exit_trait_item(&mut self, x: &mut TraitItem)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_trait_item_kind(&mut self, x: &mut TraitItemKind)
fn visit_trait_item_kind(&mut self, x: &mut TraitItemKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_trait_item_kind(&mut self, x: &mut TraitItemKind)
fn enter_trait_item_kind(&mut self, x: &mut TraitItemKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_trait_item_kind(&mut self, x: &mut TraitItemKind)
fn exit_trait_item_kind(&mut self, x: &mut TraitItemKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_item_quote_origin(&mut self, x: &mut ItemQuoteOrigin)
fn visit_item_quote_origin(&mut self, x: &mut ItemQuoteOrigin)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_item_quote_origin(&mut self, x: &mut ItemQuoteOrigin)
fn enter_item_quote_origin(&mut self, x: &mut ItemQuoteOrigin)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_item_quote_origin(&mut self, x: &mut ItemQuoteOrigin)
fn exit_item_quote_origin(&mut self, x: &mut ItemQuoteOrigin)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_item_quote_origin_kind(&mut self, x: &mut ItemQuoteOriginKind)
fn visit_item_quote_origin_kind(&mut self, x: &mut ItemQuoteOriginKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_item_quote_origin_kind(&mut self, x: &mut ItemQuoteOriginKind)
fn enter_item_quote_origin_kind(&mut self, x: &mut ItemQuoteOriginKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_item_quote_origin_kind(&mut self, x: &mut ItemQuoteOriginKind)
fn exit_item_quote_origin_kind(&mut self, x: &mut ItemQuoteOriginKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_item_quote_origin_position(&mut self, x: &mut ItemQuoteOriginPosition)
fn visit_item_quote_origin_position(&mut self, x: &mut ItemQuoteOriginPosition)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_item_quote_origin_position(&mut self, x: &mut ItemQuoteOriginPosition)
fn enter_item_quote_origin_position(&mut self, x: &mut ItemQuoteOriginPosition)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_item_quote_origin_position(&mut self, x: &mut ItemQuoteOriginPosition)
fn exit_item_quote_origin_position(&mut self, x: &mut ItemQuoteOriginPosition)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_generic_param_kind(&mut self, x: &mut GenericParamKind)
fn visit_generic_param_kind(&mut self, x: &mut GenericParamKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_generic_param_kind(&mut self, x: &mut GenericParamKind)
fn enter_generic_param_kind(&mut self, x: &mut GenericParamKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_generic_param_kind(&mut self, x: &mut GenericParamKind)
fn exit_generic_param_kind(&mut self, x: &mut GenericParamKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_impl_ident(&mut self, x: &mut ImplIdent)
fn visit_impl_ident(&mut self, x: &mut ImplIdent)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_impl_ident(&mut self, x: &mut ImplIdent)
fn enter_impl_ident(&mut self, x: &mut ImplIdent)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_impl_ident(&mut self, x: &mut ImplIdent)
fn exit_impl_ident(&mut self, x: &mut ImplIdent)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_projection_predicate(&mut self, x: &mut ProjectionPredicate)
fn visit_projection_predicate(&mut self, x: &mut ProjectionPredicate)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_projection_predicate(&mut self, x: &mut ProjectionPredicate)
fn enter_projection_predicate(&mut self, x: &mut ProjectionPredicate)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_projection_predicate(&mut self, x: &mut ProjectionPredicate)
fn exit_projection_predicate(&mut self, x: &mut ProjectionPredicate)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_generic_param(&mut self, x: &mut GenericParam)
fn visit_generic_param(&mut self, x: &mut GenericParam)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_generic_param(&mut self, x: &mut GenericParam)
fn enter_generic_param(&mut self, x: &mut GenericParam)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_generic_param(&mut self, x: &mut GenericParam)
fn exit_generic_param(&mut self, x: &mut GenericParam)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_generics(&mut self, x: &mut Generics)
fn visit_generics(&mut self, x: &mut Generics)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_generics(&mut self, x: &mut Generics)
fn enter_generics(&mut self, x: &mut Generics)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_generics(&mut self, x: &mut Generics)
fn exit_generics(&mut self, x: &mut Generics)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_doc_comment_kind(&mut self, x: &mut DocCommentKind)
fn visit_doc_comment_kind(&mut self, x: &mut DocCommentKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_doc_comment_kind(&mut self, x: &mut DocCommentKind)
fn enter_doc_comment_kind(&mut self, x: &mut DocCommentKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_doc_comment_kind(&mut self, x: &mut DocCommentKind)
fn exit_doc_comment_kind(&mut self, x: &mut DocCommentKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_param(&mut self, x: &mut Param)
fn visit_param(&mut self, x: &mut Param)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_param(&mut self, x: &mut Param)
fn enter_param(&mut self, x: &mut Param)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_param(&mut self, x: &mut Param)
fn exit_param(&mut self, x: &mut Param)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_variant(&mut self, x: &mut Variant)
fn visit_variant(&mut self, x: &mut Variant)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_variant(&mut self, x: &mut Variant)
fn enter_variant(&mut self, x: &mut Variant)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_variant(&mut self, x: &mut Variant)
fn exit_variant(&mut self, x: &mut Variant)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_item_kind(&mut self, x: &mut ItemKind)
fn visit_item_kind(&mut self, x: &mut ItemKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_item_kind(&mut self, x: &mut ItemKind)
fn enter_item_kind(&mut self, x: &mut ItemKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_item_kind(&mut self, x: &mut ItemKind)
fn exit_item_kind(&mut self, x: &mut ItemKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn enter_item(&mut self, x: &mut Item)
fn enter_item(&mut self, x: &mut Item)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_item(&mut self, x: &mut Item)
fn exit_item(&mut self, x: &mut Item)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_generic_constraint(&mut self, x: &mut GenericConstraint)
fn visit_generic_constraint(&mut self, x: &mut GenericConstraint)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_generic_constraint(&mut self, x: &mut GenericConstraint)
fn enter_generic_constraint(&mut self, x: &mut GenericConstraint)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_generic_constraint(&mut self, x: &mut GenericConstraint)
fn exit_generic_constraint(&mut self, x: &mut GenericConstraint)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_error_node(&mut self, x: &mut ErrorNode)
fn visit_error_node(&mut self, x: &mut ErrorNode)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_error_node(&mut self, x: &mut ErrorNode)
fn enter_error_node(&mut self, x: &mut ErrorNode)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_error_node(&mut self, x: &mut ErrorNode)
fn exit_error_node(&mut self, x: &mut ErrorNode)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_module(&mut self, x: &mut Module)
fn visit_module(&mut self, x: &mut Module)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_module(&mut self, x: &mut Module)
fn enter_module(&mut self, x: &mut Module)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_module(&mut self, x: &mut Module)
fn exit_module(&mut self, x: &mut Module)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_resugared_expr_kind(&mut self, x: &mut ResugaredExprKind)
fn visit_resugared_expr_kind(&mut self, x: &mut ResugaredExprKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_resugared_expr_kind(&mut self, x: &mut ResugaredExprKind)
fn enter_resugared_expr_kind(&mut self, x: &mut ResugaredExprKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_resugared_expr_kind(&mut self, x: &mut ResugaredExprKind)
fn exit_resugared_expr_kind(&mut self, x: &mut ResugaredExprKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_resugared_ty_kind(&mut self, x: &mut ResugaredTyKind)
fn visit_resugared_ty_kind(&mut self, x: &mut ResugaredTyKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_resugared_ty_kind(&mut self, x: &mut ResugaredTyKind)
fn enter_resugared_ty_kind(&mut self, x: &mut ResugaredTyKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_resugared_ty_kind(&mut self, x: &mut ResugaredTyKind)
fn exit_resugared_ty_kind(&mut self, x: &mut ResugaredTyKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_resugared_pat_kind(&mut self, x: &mut ResugaredPatKind)
fn visit_resugared_pat_kind(&mut self, x: &mut ResugaredPatKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_resugared_pat_kind(&mut self, x: &mut ResugaredPatKind)
fn enter_resugared_pat_kind(&mut self, x: &mut ResugaredPatKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_resugared_pat_kind(&mut self, x: &mut ResugaredPatKind)
fn exit_resugared_pat_kind(&mut self, x: &mut ResugaredPatKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_resugared_impl_item_kind(&mut self, x: &mut ResugaredImplItemKind)
fn visit_resugared_impl_item_kind(&mut self, x: &mut ResugaredImplItemKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_resugared_impl_item_kind(&mut self, x: &mut ResugaredImplItemKind)
fn enter_resugared_impl_item_kind(&mut self, x: &mut ResugaredImplItemKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_resugared_impl_item_kind(&mut self, x: &mut ResugaredImplItemKind)
fn exit_resugared_impl_item_kind(&mut self, x: &mut ResugaredImplItemKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_resugared_trait_item_kind(&mut self, x: &mut ResugaredTraitItemKind)
fn visit_resugared_trait_item_kind(&mut self, x: &mut ResugaredTraitItemKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_resugared_trait_item_kind(&mut self, x: &mut ResugaredTraitItemKind)
fn enter_resugared_trait_item_kind(&mut self, x: &mut ResugaredTraitItemKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_resugared_trait_item_kind(&mut self, x: &mut ResugaredTraitItemKind)
fn exit_resugared_trait_item_kind(&mut self, x: &mut ResugaredTraitItemKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_resugared_item_kind(&mut self, x: &mut ResugaredItemKind)
fn visit_resugared_item_kind(&mut self, x: &mut ResugaredItemKind)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn enter_resugared_item_kind(&mut self, x: &mut ResugaredItemKind)
fn enter_resugared_item_kind(&mut self, x: &mut ResugaredItemKind)
Called when starting to visit a
$ty (unless visit_$ty is overriden).Sourcefn exit_resugared_item_kind(&mut self, x: &mut ResugaredItemKind)
fn exit_resugared_item_kind(&mut self, x: &mut ResugaredItemKind)
Called when finished visiting a
$ty (unless visit_$ty is overriden).Sourcefn visit_span(&mut self, x: &mut Span)
fn visit_span(&mut self, x: &mut Span)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn visit_fragment(&mut self, x: &mut Fragment)
fn visit_fragment(&mut self, x: &mut Fragment)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn visit_global_id(&mut self, x: &mut GlobalId)
fn visit_global_id(&mut self, x: &mut GlobalId)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn visit_diagnostic(&mut self, x: &mut Diagnostic)
fn visit_diagnostic(&mut self, x: &mut Diagnostic)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreSourcefn visit_attr_payload(&mut self, x: &mut AttrPayload)
fn visit_attr_payload(&mut self, x: &mut AttrPayload)
Overrideable method called when visiting a
$ty. When overriding this method,
call self.visit_inner(x) to keep recursively visiting the type, or don’t call
it if the contents of x should not be visited. Read moreAuto Trait Implementations
impl<'a, V> !UnwindSafe for ErrorWrapper<'a, V>
impl<'a, V> Freeze for ErrorWrapper<'a, V>
impl<'a, V> RefUnwindSafe for ErrorWrapper<'a, V>where
V: RefUnwindSafe,
impl<'a, V> Send for ErrorWrapper<'a, V>where
V: Send,
impl<'a, V> Sync for ErrorWrapper<'a, V>where
V: Sync,
impl<'a, V> Unpin for ErrorWrapper<'a, V>
impl<'a, V> UnsafeUnpin for ErrorWrapper<'a, V>