Work with hax attributes.
Structs
- FnLike
Assocated Expressions - The various linked expressions one can usually find on a (linked or not) function.
- Linked
Item Graph - A graph of items connected via the hax attribute
AttrPayload::AssociatedItemand UUIDs. - Postcondition
- A postcondition.
- Proof
Attributes - The various linked expressions one can usually find on a (linked or not) function.
Functions
- hax_
attributes - Get an iterator over hax attributes contained in the given attributes.
- hax_
proof_ attributes - Get proof attributes attached to the item