LeanPrinter

Struct LeanPrinter 

pub struct LeanPrinter;
The Lean printer

Implementations

Source

impl LeanPrinter

pub fn printable_item(item: &Item) -> bool

A filter for items blacklisted by the Lean backend : returns false if the item is definitely not printable, but might return true on unsupported items

pub fn render_id(&self, id: &GlobalId) -> String

Render a global id using the Rendering strategy of the Lean printer. Works for both concrete and projector ids. TODO: https://github.com/cryspen/hax/issues/1660

pub fn escape(&self, id: String) -> String

Escapes local identifiers (prefixing reserved keywords with an underscore). TODO: This should be treated directly in the name rendering engine, see https://github.com/cryspen/hax/issues/1630

pub fn render_symbol(&self, symbol: Symbol) -> String

Renders a single symbol, used for anonymous implementations of typeclasses

pub fn render_last(&self, id: &GlobalId) -> String

Renders the last, most local part of an id. Used for named arguments of constructors.

Source

impl LeanPrinter

pub fn arguments<'a, 'b, A: 'a + Clone, D>( &'a self, fields: &'b [(GlobalId, D)], is_record: &bool, ) -> DocBuilder<'a, Self, A>
where &'b D: Pretty<'a, Self, A>,

Prints arguments a variant or constructor of struct, using named or unamed arguments based on the is_record flag. Used for both expressions and patterns