pub struct LeanPrinter;Expand description
The Lean printer
Implementations
Sourceimpl LeanPrinter
impl LeanPrinter
Sourcepub fn printable_item(item: &Item) -> bool
pub fn printable_item(item: &Item) -> bool
A filter for items blacklisted by the Lean backend : returns false if the item is definitely not printable, but might return true on unsupported items
Sourcepub fn render_id(&self, id: &GlobalId) -> String
pub fn render_id(&self, id: &GlobalId) -> String
Render a global id using the Rendering strategy of the Lean printer. Works for both concrete and projector ids. TODO: https://github.com/cryspen/hax/issues/1660
Sourcepub fn escape(&self, id: String) -> String
pub fn escape(&self, id: String) -> String
Escapes local identifiers (prefixing reserved keywords with an underscore). TODO: This should be treated directly in the name rendering engine, see https://github.com/cryspen/hax/issues/1630
Sourcepub fn render_symbol(&self, symbol: Symbol) -> String
pub fn render_symbol(&self, symbol: Symbol) -> String
Renders a single symbol, used for anonymous implementations of typeclasses
Sourcepub fn render_last(&self, id: &GlobalId) -> String
pub fn render_last(&self, id: &GlobalId) -> String
Renders the last, most local part of an id. Used for named arguments of constructors.
Sourceimpl LeanPrinter
impl LeanPrinter