macro_rules! pretty_ast_intersperse {
($printer: expr, $docs:expr, $sep: expr$(,)?) => { ... };
}Expand description
Convert a collection of values into documents separated by another document.
It forwards to PrettyAstExt::intersperse after materialising the
separator. The macro exists so call sites can stay concise while still
benefiting from the allocator captured by install_pretty_helpers!.