This module implements an interface to the OCaml hax engine. Via this interface, the rust engine can communicate with the OCaml engine, and reuse some of its components.
Structs
Enums
- Extended
From Engine - Extends the common
FromEnginemessages with one extra case:Response. - Query
Kind - The payload of the query.
Responsebelow mirrors this enum to represent the response from the engine. - Response
- A Response after a
Query
Functions
- initialize
- Initialize query metadata.